@@ -478,7 +478,8 @@ class Http(Interface):
     are required: ``url`` and ``method``.
 
     The ``env`` variable is a compounded dictionary of HTTP headers as well
-    as environment information passed from the webserver.
+    as environment information passed from the webserver. Sentry will explicitly
+    look for ``REMOTE_ADDR`` in ``env`` for things which require an IP address.
 
     The ``data`` variable should only contain the request body (not the query
     string). It can either be a dictionary (for standard HTTP requests) or a
@@ -697,38 +698,33 @@ class User(Interface):
     """
     An interface which describes the authenticated User for a request.
 
-    All data is arbitrary and optional other than the ``is_authenticated``
-    field which should be a boolean value indiciating whether the user
-    is logged in or not.
+    All data is arbitrary and optional other than the ``id``
+    field which should be a string representing the user's unique identifier.
 
     >>> {
-    >>>     "is_authenticated": true,
     >>>     "id": "unique_id",
-    >>>     "username": "foo",
+    >>>     "username": "my_user",
     >>>     "email": "foo@example.com"
     >>> }
     """
 
-    def __init__(self, is_authenticated, **kwargs):
-        self.is_authenticated = is_authenticated
-        self.id = kwargs.pop('id', None)
-        self.username = kwargs.pop('username', None)
-        self.email = kwargs.pop('email', None)
+    def __init__(self, id=None, email=None, username=None, **kwargs):
+        self.id = id
+        self.email = email
+        self.username = username
         self.data = kwargs
 
     def serialize(self):
-        if self.is_authenticated:
-            return {
-                'is_authenticated': self.is_authenticated,
-                'id': self.id,
-                'username': self.username,
-                'email': self.email,
-                'data': self.data,
-            }
-        else:
-            return {
-                'is_authenticated': self.is_authenticated
-            }
+        # XXX: legacy -- delete
+        if hasattr(self, 'is_authenticated'):
+            self.data['is_authenticated'] = self.is_authenticated
+
+        return {
+            'id': self.id,
+            'username': self.username,
+            'email': self.email,
+            'data': self.data,
+        }
 
     def get_hash(self):
         return []
@@ -736,7 +732,6 @@ class User(Interface):
     def to_html(self, event):
         return render_to_string('sentry/partial/interfaces/user.html', {
             'event': event,
-            'user_authenticated': self.is_authenticated,
             'user_id': self.id,
             'user_username': self.username,
             'user_email': self.email,
@@ -744,8 +739,10 @@ class User(Interface):
         })
 
     def get_search_context(self, event):
-        if not self.is_authenticated:
+        tokens = filter(bool, [self.id, self.username, self.email])
+        if not tokens:
             return {}
+
         return {
-            'text': [self.id, self.username, self.email]
+            'text': tokens
         }
