@@ -526,7 +526,7 @@ class GroupManager(BaseManager, ChartMixin):
 
         if is_new:
             try:
-                regression_signal.send(sender=self.model, instance=group)
+                regression_signal.send_robust(sender=self.model, instance=group)
             except Exception, e:
                 transaction.rollback_unless_managed(using=group._state.db)
                 logger.exception(u'Error sending regression signal: %s', e)
@@ -561,6 +561,8 @@ class GroupManager(BaseManager, ChartMixin):
             for g in groups[1:]:
                 g.delete()
             group, is_new = groups[0], False
+        else:
+            transaction.commit_unless_managed(using=group._state.db)
 
         update_kwargs = {
             'times_seen': 1,
@@ -594,7 +596,7 @@ class GroupManager(BaseManager, ChartMixin):
             silence = silence_timedelta.days * 86400 + silence_timedelta.seconds
 
             app.buffer.incr(self.model, update_kwargs, {
-                'pk': group.pk,
+                'id': group.id,
             }, extra)
         else:
             # TODO: this update should actually happen as part of create
@@ -641,10 +643,30 @@ class GroupManager(BaseManager, ChartMixin):
             ('level', event.get_level_display()),
         ]
 
+        user_ident = event.user_ident
+        if user_ident:
+            self.record_affected_user(group, user_ident)
+
         self.add_tags(group, tags)
 
         return group, is_new, is_sample
 
+    def record_affected_user(self, group, user_ident):
+        from sentry.models import AffectedUserByGroup
+
+        project = group.project
+        date = group.last_seen
+
+        app.buffer.incr(AffectedUserByGroup, {
+            'times_seen': 1,
+        }, {
+            'group': group,
+            'project': project,
+            'ident': user_ident,
+        }, {
+            'last_seen': date,
+        })
+
     def add_tags(self, group, tags):
         from sentry.models import FilterValue, FilterKey, MessageFilterValue
 
@@ -652,7 +674,7 @@ class GroupManager(BaseManager, ChartMixin):
         date = group.last_seen
 
         for key, value in itertools.ifilter(lambda x: bool(x[1]), tags):
-            if len(value) > MAX_TAG_LENGTH:
+            if not value or len(value) > MAX_TAG_LENGTH:
                 continue
 
             # TODO: FilterKey and FilterValue queries should be create's under a try/except
@@ -995,7 +1017,7 @@ class SearchDocumentManager(BaseManager):
                 ON st.document_id = sd.id
             WHERE %s
                 sd.project_id = %s
-            GROUP BY sd.id, sd.group_id, sd.total_events, sd.date_changed, sd.date_added
+            GROUP BY sd.id, sd.group_id, sd.total_events, sd.date_changed, sd.date_added, sd.project_id, sd.status
             ORDER BY %s
             LIMIT %d OFFSET %d
         """ % (
